
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JDesktopPane$AccessibleJDesktopPane__
#define __javax_swing_JDesktopPane$AccessibleJDesktopPane__

#pragma interface

#include <javax/swing/JComponent$AccessibleJComponent.h>
extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
        class AccessibleRole;
    }
    namespace swing
    {
        class JDesktopPane;
        class JDesktopPane$AccessibleJDesktopPane;
    }
  }
}

class javax::swing::JDesktopPane$AccessibleJDesktopPane : public ::javax::swing::JComponent$AccessibleJComponent
{

public: // actually protected
  JDesktopPane$AccessibleJDesktopPane(::javax::swing::JDesktopPane *);
public:
  virtual ::javax::accessibility::AccessibleRole * getAccessibleRole();
private:
  static const jlong serialVersionUID = 6079388927946077570LL;
public: // actually package-private
  ::javax::swing::JDesktopPane * __attribute__((aligned(__alignof__( ::javax::swing::JComponent$AccessibleJComponent)))) this$0;
public:
  static ::java::lang::Class class$;
};

#endif // __javax_swing_JDesktopPane$AccessibleJDesktopPane__
