
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_DocFlavor$SERVICE_FORMATTED__
#define __javax_print_DocFlavor$SERVICE_FORMATTED__

#pragma interface

#include <javax/print/DocFlavor.h>
extern "Java"
{
  namespace javax
  {
    namespace print
    {
        class DocFlavor$SERVICE_FORMATTED;
    }
  }
}

class javax::print::DocFlavor$SERVICE_FORMATTED : public ::javax::print::DocFlavor
{

public:
  DocFlavor$SERVICE_FORMATTED(::java::lang::String *);
private:
  static const jlong serialVersionUID = 6181337766266637256LL;
public:
  static ::javax::print::DocFlavor$SERVICE_FORMATTED * PAGEABLE;
  static ::javax::print::DocFlavor$SERVICE_FORMATTED * PRINTABLE;
  static ::javax::print::DocFlavor$SERVICE_FORMATTED * RENDERABLE_IMAGE;
  static ::java::lang::Class class$;
};

#endif // __javax_print_DocFlavor$SERVICE_FORMATTED__
