
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_xml_validation_TypeInfoProvider__
#define __javax_xml_validation_TypeInfoProvider__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace javax
  {
    namespace xml
    {
      namespace validation
      {
          class TypeInfoProvider;
      }
    }
  }
  namespace org
  {
    namespace w3c
    {
      namespace dom
      {
          class TypeInfo;
      }
    }
  }
}

class javax::xml::validation::TypeInfoProvider : public ::java::lang::Object
{

public: // actually protected
  TypeInfoProvider();
public:
  virtual ::org::w3c::dom::TypeInfo * getElementTypeInfo() = 0;
  virtual ::org::w3c::dom::TypeInfo * getAttributeTypeInfo(jint) = 0;
  virtual jboolean isIdAttribute(jint) = 0;
  virtual jboolean isSpecified(jint) = 0;
  static ::java::lang::Class class$;
};

#endif // __javax_xml_validation_TypeInfoProvider__
