
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JInternalFrame$JDesktopIcon$AccessibleJDesktopIcon__
#define __javax_swing_JInternalFrame$JDesktopIcon$AccessibleJDesktopIcon__

#pragma interface

#include <javax/swing/JComponent$AccessibleJComponent.h>
extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
        class AccessibleRole;
        class AccessibleValue;
    }
    namespace swing
    {
        class JInternalFrame$JDesktopIcon;
        class JInternalFrame$JDesktopIcon$AccessibleJDesktopIcon;
    }
  }
}

class javax::swing::JInternalFrame$JDesktopIcon$AccessibleJDesktopIcon : public ::javax::swing::JComponent$AccessibleJComponent
{

public: // actually protected
  JInternalFrame$JDesktopIcon$AccessibleJDesktopIcon(::javax::swing::JInternalFrame$JDesktopIcon *);
public:
  virtual ::javax::accessibility::AccessibleRole * getAccessibleRole();
  virtual ::javax::accessibility::AccessibleValue * getAccessibleValue();
  virtual ::java::lang::Number * getCurrentAccessibleValue();
  virtual ::java::lang::Number * getMaximumAccessibleValue();
  virtual ::java::lang::Number * getMinimumAccessibleValue();
  virtual jboolean setCurrentAccessibleValue(::java::lang::Number *);
private:
  static const jlong serialVersionUID = 5035560458941637802LL;
public: // actually package-private
  ::javax::swing::JInternalFrame$JDesktopIcon * __attribute__((aligned(__alignof__( ::javax::swing::JComponent$AccessibleJComponent)))) this$1;
public:
  static ::java::lang::Class class$;
};

#endif // __javax_swing_JInternalFrame$JDesktopIcon$AccessibleJDesktopIcon__
